@@ -1,11 +1,6 @@
 import unittest
 
-from slims.criteria import between_inclusive
-from slims.criteria import conjunction
-from slims.criteria import equals
-from slims.criteria import is_one_of
-from slims.criteria import is_not
-from slims.criteria import starts_with
+from slims.criteria import between_inclusive, conjunction, equals, is_not, is_one_of, starts_with
 
 
 class Test_Criteria(unittest.TestCase):
